==> mj-mockup-generator-1.0.3.tgz: package/README.md <==
# mj-mockup-generator

Simple & easy to use mockup generator from MockupsJar

[![install size](https://packagephobia.now.sh/badge?p=mj-mockup-generator)](https://packagephobia.now.sh/result?p=mj-mockup-generator)
[![Known Vulnerabilities](https://snyk.io/test/github/mockupsjar/mj-mockup-generator/badge.svg?targetFile=package.json)](https://snyk.io/test/github/mockupsjar/mj-mockup-generator?targetFile=package.json)

## Install

```
$ npm install mj-mockup-generator
```

## Usage

```js
const mockupGenerator = require('mj-mockup-generator');
const generator = new mockupGenerator({host: process.env.API_URL, key: process.env.API_TOKEN});

const data = {
    zoomLevel: 0.5,
    format: "jpg",
    input: ['https://dummyimage.com/750x1334/7dffb8/000000']
};

let response = await generator.render('iphone7-red', data);
console.log('response', response);
// {
//     status: 'success',
//         data: {
//     slug: 'iphone7-red',
//         name: 'iPhone7 RED',
//         status: 'successful',
//         zoomLevel: 0.5,
//         format: 'jpg',
//         result: {
//              url: 'https:/path.../renders/mockup-z0yIcUtWFZjFyeNU.jpg',
//              previewUrl: 'https://path.../renders/PcOniA1ANn6HLnX7-RFgaz9u5IiH7Ryud.jpg'
//     }
// }
```

![IPhone7 Red Mockuup](docs/iphone7-preview.jpg)

##### List all mockups
 
```js
const mockupGenerator = require('mj-mockup-generator');
const generator = new mockupGenerator({host: process.env.API_URL, key: process.env.API_TOKEN});

let response = await generator.list();
console.log(response);
 ```
 
##### Get info about a mockup
 
```js
const mockupGenerator = require('mj-mockup-generator');
const generator = new mockupGenerator({host: process.env.API_URL, key: process.env.API_TOKEN});

let response = await generator.getInfo('iphone7-red');
console.log(response);
```

##### Render simple mockup
 
```js
const mockupGenerator = require('mj-mockup-generator');
const generator = new mockupGenerator({host: process.env.API_URL, key: process.env.API_TOKEN});

const data = {
    zoomLevel: 0.5,
    format: "jpg",
    input: []
};

let task = await generator.render("iphone7-red", data);
console.log(task);
```

##### Render mockup with image
 
```js
const mockupGenerator = require('mj-mockup-generator');
const generator = new mockupGenerator({host: process.env.API_URL, key: process.env.API_TOKEN});

const data = {
    zoomLevel: 0.5,
    format: "jpg",
    input: ['https://dummyimage.com/750x1334/7dffb8/000000']
};

let task = await generator.render("iphone7-red", data);
console.log(task);
```

##### Render mockup with website
 
```js
const mockupGenerator = require('mj-mockup-generator');
const generator = new mockupGenerator({host: process.env.API_URL, key: process.env.API_TOKEN});

const data = {
    zoomLevel: 0.5,
    format: "jpg",
    input: ['https://m.imdb.com/title/tt2395427/']
};

let task = await generator.render("iphone7-red", data);
console.log(task);
```

==> mj-mockup-generator-1.0.5.tgz: package/README.md <==
# mj-mockup-generator

Simple & easy to use mockup generator from MockupsJar

[![install size](https://packagephobia.now.sh/badge?p=mj-mockup-generator)](https://packagephobia.now.sh/result?p=mj-mockup-generator)
[![Known Vulnerabilities](https://snyk.io/test/github/mockupsjar/mj-mockup-generator/badge.svg?targetFile=package.json)](https://snyk.io/test/github/mockupsjar/mj-mockup-generator?targetFile=package.json)

## Install

```
$ npm install mj-mockup-generator
```

## How to get a token

- Register an user on https://mockupsjar.com/
- Go to your profile page and generate a token https://mockupsjar.com/profile
- Use the token with your preferred API tool or library ([Postman](https://www.postman.com/) or [Axios](https://github.com/axios/axios))

Free Tier: 50 tasks for starting up & 10 extra free tasks / month

## Usage

```js
const mockupGenerator = require('mj-mockup-generator');
const generator = new mockupGenerator({key: process.env.API_TOKEN});

const data = {
    zoomLevel: 0.5,
    format: "jpg",
    input: ['https://dummyimage.com/750x1334/7dffb8/000000']
};

let response = await generator.render('iphone7-red', data);
console.log('response', response);
```

##### List all mockups
 
```js
const mockupGenerator = require('mj-mockup-generator');
const generator = new mockupGenerator({key: process.env.API_TOKEN});

let response = await generator.list();
console.log(response);
 ```
 
##### Get info about a mockup
 
```js
const mockupGenerator = require('mj-mockup-generator');
const generator = new mockupGenerator({key: process.env.API_TOKEN});

let response = await generator.getInfo('iphone7-red');
console.log(response);
```

##### Render simple mockup
 
```js
const mockupGenerator = require('mj-mockup-generator');
const generator = new mockupGenerator({key: process.env.API_TOKEN});

const data = {
    zoomLevel: 0.5,
    format: "jpg",
    input: []
};

let task = await generator.render("iphone7-red", data);
console.log(task);
```

##### Render mockup with image
 
```js
const mockupGenerator = require('mj-mockup-generator');
const generator = new mockupGenerator({key: process.env.API_TOKEN});

const data = {
    zoomLevel: 0.5,
    format: "jpg",
    input: ['https://dummyimage.com/750x1334/7dffb8/000000']
};

let task = await generator.render("iphone7-red", data);
console.log(task);
```

##### Render mockup with website
 
```js
const mockupGenerator = require('mj-mockup-generator');
const generator = new mockupGenerator({key: process.env.API_TOKEN});

const data = {
    zoomLevel: 0.5,
    format: "jpg",
    input: ['https://m.imdb.com/title/tt2395427/']
};

let task = await generator.render("iphone7-red", data);
console.log(task);
```

## Resources

[MockupsJar](https://mockupsjar.com/)

[MockupsJar API Doc](https://mockupsjar.com/apidoc)

[MockupsJar NPM Package](https://www.npmjs.com/package/mj-mockup-generator)
